from setuptools import setup, find_packages

from pathlib import Path
import shutil
import sys
import re

this_dir = Path.cwd()
root_dir = this_dir.parent

# get version number from basthon_base.js
basthonjs = root_dir / "src" / "basthon-js" / "basthon_base.js"
# trick to get version at wheel build (build is done in /tmp/...)
if not basthonjs.exists():
    basthonjs = this_dir / "basthon-kernel" / "data" / "basthon_base.js"
# version number from basthon.js using regex
with open(basthonjs) as f:
    BASTHON_KERNEL_VERSION = re.search(
        "__version__ = \"(?P<version>.*)\";", f.read()).group('version')
# make sure we have a version number
assert BASTHON_KERNEL_VERSION


with open("README.md") as f:
    LONG_DESCRIPTION = f.read()

command = sys.argv[1]

if command == "sdist":

    # use version number for cache busting
    src_dest = ((root_dir / "src" / "basthon-js", ('*.js', '*.js.map'), '.'),
                (root_dir / "src" / "basthon-py" / "build", ('*.js', '*.data'), Path(BASTHON_KERNEL_VERSION) / "basthon-py"),
                (root_dir / "src" / "modules", ('*.whl',), Path(BASTHON_KERNEL_VERSION) / "modules"),
                (root_dir / "src" / "modules", ('extern/*',), Path(BASTHON_KERNEL_VERSION) / "modules" / "extern"))

    # before creating the distribution, copy files from other locations in
    # the repository
    print("copying files...")
    basthon_dir = this_dir / "basthon-kernel"
    data_dir = basthon_dir / "data"

    # copy files from basthon into data_dir
    content = []

    for src, globs, dest in src_dest:
        for glob in globs:
            for path in src.rglob(glob):
                if path.is_file():
                    dst = data_dir / dest / path.name
                    dst.parent.mkdir(parents=True, exist_ok=True)
                    shutil.copyfile(path, dst)

setup(
    name='basthon-kernel',

    version=BASTHON_KERNEL_VERSION,
    description=('Basthon-kernel is used in Basthon Notebook'
                 ' and Basthon Console projects to provide '
                 'Python interpreter in the browser.'),

    long_description=LONG_DESCRIPTION,

    long_description_content_type="text/markdown",

    # The project's main homepage.
    url='https://framagit.org/casatir/basthon-kernel/',

    # Author details
    author='Romain Casati',
    author_email='romain.casati@ac-orleans-tours.fr',

    packages=find_packages(),

    # Choose your license
    license='License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Interpreters',

        'Operating System :: OS Independent',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
    ],

    # What does your project relate to?
    keywords='Python browser',
    
    # since https://github.com/pypa/setuptools/issues/1806
    # is still open...
    package_data={
        'basthon-kernel': ['data/*.*', 'data/*/*.*', 'data/*/*/*.*', 'data/*/*/*/*.*']
    },


)
